#!/bin/sh -x

# Software Update script

# Possible return values:

NO_UPDATE_REQUIRED=0
ERROR_BAD_DOWNLOAD=6
INSTALL_FAILED=7
INSTALL_SUCCEEDED=8
INVALID_RETURN_CODE=99
WGET_OPT=--timeout=15
UPDATE_LOCATION="/cache/glass/update/"

download() {
cd $UPDATE_LOCATION
i=1
echo "Downloading file $1..." > /dev/tty0

while [ $i -lt 30 ]
do
	
	/diags/busybox wget $1 2> /dev/tty0
	WGET_STATUS=$?
	
	if [ $WGET_STATUS -eq 0 ]
	then
		break;
	fi

	i=`expr $i + 1`
	
	sleep 1
done
if [ $i == 30 ]
then
	echo "Error while downloading file $1 !" > /dev/tty0
	exit $RET
fi

}

/diags/busybox clear > /dev/tty0
echo "" > /dev/tty0
echo " Starting the software update . . ." > /dev/tty0
echo "" > /dev/tty0
sleep 1

# assign home as argv[1] or else use /root as default

if [ -z $1 ]
then
	HOME=/root
else
	HOME=$1
fi

echo "Check update started with HOME=$HOME at`date`"

RET=$INVALID_RETURN_CODE

# This is the current version of the software as stored in the file $CURR_VERSION_FILE
CURR_VERSION=`getprop glass.release.version`

# If we can't read the current version, assume something bad has happened and get the latest version of the software
if [ -z $CURR_VERSION ]
then
	CURR_VERSION=0
fi

VENDOR_NAME=`getprop vendor.name`
MODEL_NAME=`getprop ro.product.model`

echo "" > /dev/tty0
echo " The current verion for model $MODEL_NAME is $CURR_VERSION" > /dev/tty0
echo "" > /dev/tty0
echo " Checking the available version on the server . . ." > /dev/tty0
if [ "$VENDOR_NAME" == "vixtel" ]
then
	UPDATE_URL="http://vixtel.cloudtc.com"

    	if [ "$MODEL_NAME" == "1100" ]
	then
		UPDATE_URL="$UPDATE_URL/phone/vixtel1100"
	else
		UPDATE_URL="$UPDATE_URL/phone/vixtel1000"
	fi
       
else
	UPDATE_URL="http://updates.cloudtc.com"
	if [ "$MODEL_NAME" == "IP150" ]
	then
		UPDATE_URL="$UPDATE_URL/phone/IP150"
	else
		if [ "$MODEL_NAME" == "1100" ]
		then
			UPDATE_URL="$UPDATE_URL/phone/1100"
		else
			UPDATE_URL="$UPDATE_URL/phone/1000"
		fi
	fi
fi

echo "" > /dev/tty0
echo " Fetching the software update version from:  $UPDATE_URL" > /dev/tty0

i=0

while [ $i -lt 30 ]
do
	# Get the version number available on the server
	AVAIL_VERSION=`/diags/busybox wget $WGET_OPT -O - $UPDATE_URL/update.current`

	WGET_STATUS=$?
	
	if [ $WGET_STATUS -eq 0 ]
	then
		break;
	fi

	i=`expr $i + 1`
	
	sleep 1
done

if [ "$MODEL_NAME" == "IP150" ]
then
	AVAIL_VERSION=${AVAIL_VERSION#*:}
fi

echo " Available version on the server is $AVAIL_VERSION" > /dev/tty0
	
# If we can't get the version number of the latest version, abort
if [ -z $AVAIL_VERSION ]
then
	echo " Fatal: wget could not retrieve current latest version on server" > /dev/tty0
	exit $NO_AVAIL_VERSION
fi

# Now we have both current and available version, download and install the new version

if [ "$AVAIL_VERSION" -ge "$CURR_VERSION" ]
then
	echo "" > /dev/tty0
	echo " Downloading software update version: $AVAIL_VERSION" > /dev/tty0

	# Install update
	if [ -d $UPDATE_LOCATION ]
	then
		/diags/busybox rm -r $UPDATE_LOCATION
	fi
	/diags/busybox mkdir -p $UPDATE_LOCATION
	
	
	DOWNLOAD_FILE="android-rootfs-$AVAIL_VERSION.tar.bz2"
	download "$UPDATE_URL/$AVAIL_VERSION/$DOWNLOAD_FILE"
	DOWNLOAD_FILE="android-rootfs-$AVAIL_VERSION.tar.bz2.md5"
	download $UPDATE_URL/$AVAIL_VERSION/$DOWNLOAD_FILE
	DOWNLOAD_FILE="android-boot-$AVAIL_VERSION.tar.bz2"
	download $UPDATE_URL/$AVAIL_VERSION/$DOWNLOAD_FILE
	DOWNLOAD_FILE="android-boot-$AVAIL_VERSION.tar.bz2.md5"
	download $UPDATE_URL/$AVAIL_VERSION/$DOWNLOAD_FILE

	echo "" > /dev/tty0
	echo " Checking the downloaded files . . ." > /dev/tty0
	
	#Execute check-update.sh
	/cloud/check-update.sh $AVAIL_VERSION
	CHECK_UPDATE_STATUS=$?
	
	
	if [ $CHECK_UPDATE_STATUS -ne 0 ]
	then
		echo "" > /dev/tty0
		echo " Unable to fully download software update files, please check your Internet connnection." > /dev/tty0
		exit $RET	
	fi

	echo "" > /dev/tty0
	echo " Software update files are downloaded successfully." > /dev/tty0
	
	echo "" > /dev/tty0
	echo " Installing the software update. Please wait . . ." > /dev/tty0

	#Execute install-update.sh
	/cloud/install-update.sh $AVAIL_VERSION
	INSTALL_UPDATE_STATUS=$?
	
	if [ $INSTALL_UPDATE_STATUS -ne 0 ]
	then
		echo " Update install failed with code: $INSTALL_UPDATE_STATUS" > /dev/tty0
		exit $RET	
	else
		echo "" > /dev/tty0
		echo "------------------------------------------------------" > /dev/tty0
		echo " Phone is successfully updated to $AVAIL_VERSION" > /dev/tty0
		echo "------------------------------------------------------" > /dev/tty0
		echo "" > /dev/tty0
		echo " Please wait. Phone will automatically reboot in some time." > /dev/tty0
		sleep 5
		#Create reboot flag for install-service.sh
		/diags/busybox mkdir -p /cloud/install/reboot
		RET=$INSTALL_SUCCEEDED
	fi	
	
else
	echo " Current version $CURR_VERSION is up-to-date" > /dev/tty0
	RET=$NO_UPDATE_REQUIRED
fi

if [ $RET -eq 99 ]
then
	echo "Returning with invalid value!!!"
fi

exit $RET

